use clap::{Arg, Command, ArgMatches};
use crate::commands::config::ConfigSetArgs;

use crate::commands;

pub fn create() -> Command {
    Command::new("config")
        .about("Get and set repository or global options")
        .subcommand(
            Command::new("get")
            .about("Get the value of a configuration variable")
            .arg(
                Arg::new("name")
                .help("The name of the configuration variable")
                .required(true)
                .index(1)
                )
            )
        .subcommand(
            Command::new("set")
            .about("Set a configuration variable")
            .arg(
                Arg::new("name")
                .help("The name of the configuration variable")
                .required(true)
                .index(1)
                )
            .arg(
                Arg::new("value")
                .help("The value to set")
                .required(true)
                .index(2)
                )
            )
}

pub fn handler(args: &ArgMatches) {

    match args.subcommand() {
        Some(("set", set_matches)) => {
            commands::config::config_set(ConfigSetArgs {
                name: set_matches.get_one::<String>("name").unwrap().to_string(),
                value: set_matches.get_one::<String>("value").unwrap().to_string(),
            });
        }
        _ => println!("Invalid or missing subcommand for 'config'"),
    }
}
