use clap::{Arg, Command, ArgMatches, ArgAction};

use crate::commands;
use crate::commands::remote::RemoteArgs;

pub fn create() -> Command {
    Command::new("remote")
        .about("Manage set of tracked repositories")
        .subcommand(
            Command::new("add")
            .arg(
                Arg::new("name")
                .required(true)
                .index(1)
                .help("The name of the remote"),
                )
            .arg(
                Arg::new("url")
                .required(true)
                .index(2)
                .help("The url of the remote"),
                )
            .about("Add a new remote to this repository")
            )
        .arg(
            Arg::new("verbose")
            .short('v')
            .long("verbose")
            .action(ArgAction::SetTrue)
            .help("Be a little more verbose and show remote url after name.")
            )
}

pub fn handler(args: &ArgMatches) {
    match args.subcommand() {
        Some(("add", add_matches)) => {
            commands::remote::remote_add(RemoteArgs {
                name: add_matches.get_one::<String>("name").unwrap().to_string(),
                url: add_matches.get_one::<String>("url").unwrap().to_string(),
            });
        }
        _ => {
            commands::remote::remote_list(*args.get_one::<bool>("verbose").unwrap());
        }
    }
}
